package v1
import "go.opentelemetry.io/proto/otlp/common/v1"
Index ¶
- Variables
- type AnyValue
- func (*AnyValue) Descriptor() ([]byte, []int)
- func (x *AnyValue) GetArrayValue() *ArrayValue
- func (x *AnyValue) GetBoolValue() bool
- func (x *AnyValue) GetBytesValue() []byte
- func (x *AnyValue) GetDoubleValue() float64
- func (x *AnyValue) GetIntValue() int64
- func (x *AnyValue) GetKvlistValue() *KeyValueList
- func (x *AnyValue) GetStringValue() string
- func (m *AnyValue) GetValue() isAnyValue_Value
- func (*AnyValue) ProtoMessage()
- func (x *AnyValue) ProtoReflect() protoreflect.Message
- func (x *AnyValue) Reset()
- func (x *AnyValue) String() string
- type AnyValue_ArrayValue
- type AnyValue_BoolValue
- type AnyValue_BytesValue
- type AnyValue_DoubleValue
- type AnyValue_IntValue
- type AnyValue_KvlistValue
- type AnyValue_StringValue
- type ArrayValue
- func (*ArrayValue) Descriptor() ([]byte, []int)
- func (x *ArrayValue) GetValues() []*AnyValue
- func (*ArrayValue) ProtoMessage()
- func (x *ArrayValue) ProtoReflect() protoreflect.Message
- func (x *ArrayValue) Reset()
- func (x *ArrayValue) String() string
- type EntityRef
- func (*EntityRef) Descriptor() ([]byte, []int)
- func (x *EntityRef) GetDescriptionKeys() []string
- func (x *EntityRef) GetIdKeys() []string
- func (x *EntityRef) GetSchemaUrl() string
- func (x *EntityRef) GetType() string
- func (*EntityRef) ProtoMessage()
- func (x *EntityRef) ProtoReflect() protoreflect.Message
- func (x *EntityRef) Reset()
- func (x *EntityRef) String() string
- type InstrumentationScope
- func (*InstrumentationScope) Descriptor() ([]byte, []int)
- func (x *InstrumentationScope) GetAttributes() []*KeyValue
- func (x *InstrumentationScope) GetDroppedAttributesCount() uint32
- func (x *InstrumentationScope) GetName() string
- func (x *InstrumentationScope) GetVersion() string
- func (*InstrumentationScope) ProtoMessage()
- func (x *InstrumentationScope) ProtoReflect() protoreflect.Message
- func (x *InstrumentationScope) Reset()
- func (x *InstrumentationScope) String() string
- type KeyValue
- func (*KeyValue) Descriptor() ([]byte, []int)
- func (x *KeyValue) GetKey() string
- func (x *KeyValue) GetValue() *AnyValue
- func (*KeyValue) ProtoMessage()
- func (x *KeyValue) ProtoReflect() protoreflect.Message
- func (x *KeyValue) Reset()
- func (x *KeyValue) String() string
- type KeyValueList
Variables ¶
var File_opentelemetry_proto_common_v1_common_proto protoreflect.FileDescriptor
Types ¶
type AnyValue ¶
type AnyValue struct {
// The value is one of the listed fields. It is valid for all values to be unspecified
// in which case this AnyValue is considered to be "empty".
//
// Types that are assignable to Value:
// *AnyValue_StringValue
// *AnyValue_BoolValue
// *AnyValue_IntValue
// *AnyValue_DoubleValue
// *AnyValue_ArrayValue
// *AnyValue_KvlistValue
// *AnyValue_BytesValue
Value isAnyValue_Value `protobuf_oneof:"value"`
// contains filtered or unexported fields
}
Represents any type of attribute value. AnyValue may contain a primitive value such as a string or integer or it may contain an arbitrary nested object containing arrays, key-value lists and primitives.
func (*AnyValue) Descriptor ¶
Deprecated: Use AnyValue.ProtoReflect.Descriptor instead.
func (*AnyValue) GetArrayValue ¶
func (x *AnyValue) GetArrayValue() *ArrayValue
func (*AnyValue) GetBoolValue ¶
func (*AnyValue) GetBytesValue ¶
func (*AnyValue) GetDoubleValue ¶
func (*AnyValue) GetIntValue ¶
func (*AnyValue) GetKvlistValue ¶
func (x *AnyValue) GetKvlistValue() *KeyValueList
func (*AnyValue) GetStringValue ¶
func (*AnyValue) GetValue ¶
func (m *AnyValue) GetValue() isAnyValue_Value
func (*AnyValue) ProtoMessage ¶
func (*AnyValue) ProtoMessage()
func (*AnyValue) ProtoReflect ¶
func (x *AnyValue) ProtoReflect() protoreflect.Message
func (*AnyValue) Reset ¶
func (x *AnyValue) Reset()
func (*AnyValue) String ¶
type AnyValue_ArrayValue ¶
type AnyValue_ArrayValue struct {
ArrayValue *ArrayValue `protobuf:"bytes,5,opt,name=array_value,json=arrayValue,proto3,oneof"`
}
type AnyValue_BoolValue ¶
type AnyValue_BoolValue struct {
BoolValue bool `protobuf:"varint,2,opt,name=bool_value,json=boolValue,proto3,oneof"`
}
type AnyValue_BytesValue ¶
type AnyValue_BytesValue struct {
BytesValue []byte `protobuf:"bytes,7,opt,name=bytes_value,json=bytesValue,proto3,oneof"`
}
type AnyValue_DoubleValue ¶
type AnyValue_DoubleValue struct {
DoubleValue float64 `protobuf:"fixed64,4,opt,name=double_value,json=doubleValue,proto3,oneof"`
}
type AnyValue_IntValue ¶
type AnyValue_IntValue struct {
IntValue int64 `protobuf:"varint,3,opt,name=int_value,json=intValue,proto3,oneof"`
}
type AnyValue_KvlistValue ¶
type AnyValue_KvlistValue struct {
KvlistValue *KeyValueList `protobuf:"bytes,6,opt,name=kvlist_value,json=kvlistValue,proto3,oneof"`
}
type AnyValue_StringValue ¶
type AnyValue_StringValue struct {
StringValue string `protobuf:"bytes,1,opt,name=string_value,json=stringValue,proto3,oneof"`
}
type ArrayValue ¶
type ArrayValue struct {
// Array of values. The array may be empty (contain 0 elements).
Values []*AnyValue `protobuf:"bytes,1,rep,name=values,proto3" json:"values,omitempty"`
// contains filtered or unexported fields
}
ArrayValue is a list of AnyValue messages. We need ArrayValue as a message since oneof in AnyValue does not allow repeated fields.
func (*ArrayValue) Descriptor ¶
func (*ArrayValue) Descriptor() ([]byte, []int)
Deprecated: Use ArrayValue.ProtoReflect.Descriptor instead.
func (*ArrayValue) GetValues ¶
func (x *ArrayValue) GetValues() []*AnyValue
func (*ArrayValue) ProtoMessage ¶
func (*ArrayValue) ProtoMessage()
func (*ArrayValue) ProtoReflect ¶
func (x *ArrayValue) ProtoReflect() protoreflect.Message
func (*ArrayValue) Reset ¶
func (x *ArrayValue) Reset()
func (*ArrayValue) String ¶
func (x *ArrayValue) String() string
type EntityRef ¶
type EntityRef struct {
// The Schema URL, if known. This is the identifier of the Schema that the entity data
// is recorded in. To learn more about Schema URL see
// https://opentelemetry.io/docs/specs/otel/schemas/#schema-url
//
// This schema_url applies to the data in this message and to the Resource attributes
// referenced by id_keys and description_keys.
// TODO: discuss if we are happy with this somewhat complicated definition of what
// the schema_url applies to.
//
// This field obsoletes the schema_url field in ResourceMetrics/ResourceSpans/ResourceLogs.
SchemaUrl string `protobuf:"bytes,1,opt,name=schema_url,json=schemaUrl,proto3" json:"schema_url,omitempty"`
// Defines the type of the entity. MUST not change during the lifetime of the entity.
// For example: "service" or "host". This field is required and MUST not be empty
// for valid entities.
Type string `protobuf:"bytes,2,opt,name=type,proto3" json:"type,omitempty"`
// Attribute Keys that identify the entity.
// MUST not change during the lifetime of the entity. The Id must contain at least one attribute.
// These keys MUST exist in the containing {message}.attributes.
IdKeys []string `protobuf:"bytes,3,rep,name=id_keys,json=idKeys,proto3" json:"id_keys,omitempty"`
// Descriptive (non-identifying) attribute keys of the entity.
// MAY change over the lifetime of the entity. MAY be empty.
// These attribute keys are not part of entity's identity.
// These keys MUST exist in the containing {message}.attributes.
DescriptionKeys []string `protobuf:"bytes,4,rep,name=description_keys,json=descriptionKeys,proto3" json:"description_keys,omitempty"`
// contains filtered or unexported fields
}
A reference to an Entity. Entity represents an object of interest associated with produced telemetry: e.g spans, metrics, profiles, or logs.
Status: [Development]
func (*EntityRef) Descriptor ¶
Deprecated: Use EntityRef.ProtoReflect.Descriptor instead.
func (*EntityRef) GetDescriptionKeys ¶
func (*EntityRef) GetIdKeys ¶
func (*EntityRef) GetSchemaUrl ¶
func (*EntityRef) GetType ¶
func (*EntityRef) ProtoMessage ¶
func (*EntityRef) ProtoMessage()
func (*EntityRef) ProtoReflect ¶
func (x *EntityRef) ProtoReflect() protoreflect.Message
func (*EntityRef) Reset ¶
func (x *EntityRef) Reset()
func (*EntityRef) String ¶
type InstrumentationScope ¶
type InstrumentationScope struct {
// A name denoting the Instrumentation scope.
// An empty instrumentation scope name means the name is unknown.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Defines the version of the instrumentation scope.
// An empty instrumentation scope version means the version is unknown.
Version string `protobuf:"bytes,2,opt,name=version,proto3" json:"version,omitempty"`
// Additional attributes that describe the scope. [Optional].
// Attribute keys MUST be unique (it is not allowed to have more than one
// attribute with the same key).
// The behavior of software that receives duplicated keys can be unpredictable.
Attributes []*KeyValue `protobuf:"bytes,3,rep,name=attributes,proto3" json:"attributes,omitempty"`
// The number of attributes that were discarded. Attributes
// can be discarded because their keys are too long or because there are too many
// attributes. If this value is 0, then no attributes were dropped.
DroppedAttributesCount uint32 `protobuf:"varint,4,opt,name=dropped_attributes_count,json=droppedAttributesCount,proto3" json:"dropped_attributes_count,omitempty"`
// contains filtered or unexported fields
}
InstrumentationScope is a message representing the instrumentation scope information such as the fully qualified name and version.
func (*InstrumentationScope) Descriptor ¶
func (*InstrumentationScope) Descriptor() ([]byte, []int)
Deprecated: Use InstrumentationScope.ProtoReflect.Descriptor instead.
func (*InstrumentationScope) GetAttributes ¶
func (x *InstrumentationScope) GetAttributes() []*KeyValue
func (*InstrumentationScope) GetDroppedAttributesCount ¶
func (x *InstrumentationScope) GetDroppedAttributesCount() uint32
func (*InstrumentationScope) GetName ¶
func (x *InstrumentationScope) GetName() string
func (*InstrumentationScope) GetVersion ¶
func (x *InstrumentationScope) GetVersion() string
func (*InstrumentationScope) ProtoMessage ¶
func (*InstrumentationScope) ProtoMessage()
func (*InstrumentationScope) ProtoReflect ¶
func (x *InstrumentationScope) ProtoReflect() protoreflect.Message
func (*InstrumentationScope) Reset ¶
func (x *InstrumentationScope) Reset()
func (*InstrumentationScope) String ¶
func (x *InstrumentationScope) String() string
type KeyValue ¶
type KeyValue struct {
// The key name of the pair.
Key string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
// The value of the pair.
Value *AnyValue `protobuf:"bytes,2,opt,name=value,proto3" json:"value,omitempty"`
// contains filtered or unexported fields
}
Represents a key-value pair that is used to store Span attributes, Link attributes, etc.
func (*KeyValue) Descriptor ¶
Deprecated: Use KeyValue.ProtoReflect.Descriptor instead.
func (*KeyValue) GetKey ¶
func (*KeyValue) GetValue ¶
func (*KeyValue) ProtoMessage ¶
func (*KeyValue) ProtoMessage()
func (*KeyValue) ProtoReflect ¶
func (x *KeyValue) ProtoReflect() protoreflect.Message
func (*KeyValue) Reset ¶
func (x *KeyValue) Reset()
func (*KeyValue) String ¶
type KeyValueList ¶
type KeyValueList struct {
// A collection of key/value pairs of key-value pairs. The list may be empty (may
// contain 0 elements).
//
// The keys MUST be unique (it is not allowed to have more than one
// value with the same key).
// The behavior of software that receives duplicated keys can be unpredictable.
Values []*KeyValue `protobuf:"bytes,1,rep,name=values,proto3" json:"values,omitempty"`
// contains filtered or unexported fields
}
KeyValueList is a list of KeyValue messages. We need KeyValueList as a message since `oneof` in AnyValue does not allow repeated fields. Everywhere else where we need a list of KeyValue messages (e.g. in Span) we use `repeated KeyValue` directly to avoid unnecessary extra wrapping (which slows down the protocol). The 2 approaches are semantically equivalent.
func (*KeyValueList) Descriptor ¶
func (*KeyValueList) Descriptor() ([]byte, []int)
Deprecated: Use KeyValueList.ProtoReflect.Descriptor instead.
func (*KeyValueList) GetValues ¶
func (x *KeyValueList) GetValues() []*KeyValue
func (*KeyValueList) ProtoMessage ¶
func (*KeyValueList) ProtoMessage()
func (*KeyValueList) ProtoReflect ¶
func (x *KeyValueList) ProtoReflect() protoreflect.Message
func (*KeyValueList) Reset ¶
func (x *KeyValueList) Reset()
func (*KeyValueList) String ¶
func (x *KeyValueList) String() string
Source Files ¶
common.pb.go
- Version
- v1.9.0 (latest)
- Published
- Nov 3, 2025
- Platform
- linux/amd64
- Imports
- 4 packages
- Last checked
- 4 months ago –
Tools for package owners.