package v1
import "go.opentelemetry.io/proto/otlp/resource/v1"
Index ¶
- Variables
- type Resource
- func (*Resource) Descriptor() ([]byte, []int)
- func (x *Resource) GetAttributes() []*v1.KeyValue
- func (x *Resource) GetDroppedAttributesCount() uint32
- func (x *Resource) GetEntityRefs() []*v1.EntityRef
- func (*Resource) ProtoMessage()
- func (x *Resource) ProtoReflect() protoreflect.Message
- func (x *Resource) Reset()
- func (x *Resource) String() string
Variables ¶
var File_opentelemetry_proto_resource_v1_resource_proto protoreflect.FileDescriptor
Types ¶
type Resource ¶
type Resource struct {
// Set of attributes that describe the resource.
// Attribute keys MUST be unique (it is not allowed to have more than one
// attribute with the same key).
// The behavior of software that receives duplicated keys can be unpredictable.
Attributes []*v1.KeyValue `protobuf:"bytes,1,rep,name=attributes,proto3" json:"attributes,omitempty"`
// The number of dropped attributes. If the value is 0, then
// no attributes were dropped.
DroppedAttributesCount uint32 `protobuf:"varint,2,opt,name=dropped_attributes_count,json=droppedAttributesCount,proto3" json:"dropped_attributes_count,omitempty"`
// Set of entities that participate in this Resource.
//
// Note: keys in the references MUST exist in attributes of this message.
//
// Status: [Development]
EntityRefs []*v1.EntityRef `protobuf:"bytes,3,rep,name=entity_refs,json=entityRefs,proto3" json:"entity_refs,omitempty"`
// contains filtered or unexported fields
}
Resource information.
func (*Resource) Descriptor ¶
Deprecated: Use Resource.ProtoReflect.Descriptor instead.
func (*Resource) GetAttributes ¶
func (*Resource) GetDroppedAttributesCount ¶
func (*Resource) GetEntityRefs ¶
func (*Resource) ProtoMessage ¶
func (*Resource) ProtoMessage()
func (*Resource) ProtoReflect ¶
func (x *Resource) ProtoReflect() protoreflect.Message
func (*Resource) Reset ¶
func (x *Resource) Reset()
func (*Resource) String ¶
Source Files ¶
resource.pb.go
- Version
- v1.9.0 (latest)
- Published
- Nov 3, 2025
- Platform
- linux/amd64
- Imports
- 5 packages
- Last checked
- 4 months ago –
Tools for package owners.